@@ -106,19 +106,19 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    // if somethings goes wrong with the parsing, we don't have deleted the old contents
    CatalogItem tempHeader;
 
-   qDebug() << "start parsing...";
+   //qDebug() << "start parsing...";
    QTime aaa;
    aaa.start();
    // first read header
    const ConversionStatus status = readEntry(stream);
 
    bool recoveredErrorInHeader = false;
-   if (KDE_ISUNLIKELY( status == RECOVERED_PARSE_ERROR ))
+   if (Q_UNLIKELY( status == RECOVERED_PARSE_ERROR ))
    {
       qDebug() << "Recovered error in header entry";
       recoveredErrorInHeader = true;
    }
-   else if (KDE_ISUNLIKELY( status != OK ))
+   else if (Q_UNLIKELY( status != OK ))
    {
       qWarning() << "Parse error in header entry";
       return status;
@@ -127,7 +127,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    bool reconstructedHeader=!_msgid.isEmpty() && !_msgid.first().isEmpty();
    //qWarning() << "HEADER MSGID: " << _msgid;
    //qWarning() << "HEADER MSGSTR: " << _msgstr;
-   if (KDE_ISUNLIKELY( reconstructedHeader ))
+   if (Q_UNLIKELY( reconstructedHeader ))
    {
       // The header must have an empty msgid
       qWarning() << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
@@ -177,7 +177,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
       else
          success=readEntry(stream);
 
-      if(KDE_ISLIKELY(success==OK))
+      if(Q_LIKELY(success==OK))
       {
          if( _obsolete )
             _extraDataSaver(_comment);
@@ -197,7 +197,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
                   docbookFile = tempCatItem.comment().contains(".docbook" );
          }
       }
-      else if(KDE_ISUNLIKELY( success==RECOVERED_PARSE_ERROR ))
+      else if(Q_UNLIKELY( success==RECOVERED_PARSE_ERROR ))
       {
          qDebug() << "Recovered parse error in entry: " << counter;
          //recoveredError=true;
@@ -229,14 +229,14 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    }
 
    // TODO: can we check that there is no useful entry?
-   if (KDE_ISUNLIKELY( !counter && !recoveredErrorInHeader ))
+   if (Q_UNLIKELY( !counter && !recoveredErrorInHeader ))
    {
       // Empty file? (Otherwise, there would be a try of getting an entry and the count would be 1 !)
       qDebug() << " Empty file?";
       return PARSE_ERROR;
    }
 
-   qDebug() << " ready";
+   //qDebug() << " ready";
 
    // We have successfully loaded the file (perhaps with recovered errors)
 
@@ -249,12 +249,12 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    setCodec(codec);
    //setMimeTypes( "text/x-gettext-translation" );
 #if 0
-   if (KDE_ISUNLIKELY( recoveredErrorInHeader ))
+   if (Q_UNLIKELY( recoveredErrorInHeader ))
    {
       qDebug() << " Returning: header error";
       return RECOVERED_HEADER_ERROR;
    }
-   else if (KDE_ISUNLIKELY( recoveredError ))
+   else if (Q_UNLIKELY( recoveredError ))
    {
       qDebug() << " Returning: recovered parse error";
       return RECOVERED_PARSE_ERROR;
@@ -262,7 +262,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    else
 #endif
    {
-      qDebug() << " Returning: OK! :-)";
+      //qDebug() << " Returning: OK! :-)";
       return OK;
    }
 }
@@ -277,7 +277,7 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
     QTextCodec* codec=stream.codec();  //detect UTF-16
 
     ConversionStatus status = readEntry(stream);
-    if (KDE_ISUNLIKELY( status!=OK && status != RECOVERED_PARSE_ERROR ))
+    if (Q_UNLIKELY( status!=OK && status != RECOVERED_PARSE_ERROR ))
     {
         qDebug() << "wasn't able to read header";
         return codec;
@@ -291,7 +291,7 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
     }
 
     const QString charset = regexp.cap(1);
-    qDebug() << "charset: " << charset;
+    if (charset!=QLatin1String("UTF-8")) qDebug() << "charset:" << charset;
 
     if (charset.isEmpty())
     {
@@ -322,9 +322,11 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
 ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
 {
    ConversionStatus result=readEntryRaw(stream);
-   _msgstr.replaceInStrings(QStringLiteral("\\\""),QStringLiteral("\""));
-   _msgid.replaceInStrings(QStringLiteral("\\\""),QStringLiteral("\""));
-   _msgctxt.replace(QStringLiteral("\\\""),QStringLiteral("\""));
+   const QString FROM = QStringLiteral("\\\"");
+   const QString TO = QStringLiteral("\"");
+   _msgstr.replaceInStrings(FROM, TO);
+   _msgid.replaceInStrings(FROM, TO);
+   _msgctxt.replace(FROM, TO);
    return result;
 }
 
@@ -365,7 +367,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
        static const QString lesslessless=QStringLiteral("<<<<<<<");
        static const QString isisis=QStringLiteral("=======");
        static const QString moremoremore=QStringLiteral(">>>>>>>");
-       if (KDE_ISUNLIKELY( line.startsWith( lesslessless ) || line.startsWith( isisis ) || line.startsWith( moremoremore ) ))
+       if (Q_UNLIKELY( line.startsWith( lesslessless ) || line.startsWith( isisis ) || line.startsWith( moremoremore ) ))
        {
           // We have found a CVS/SVN conflict marker. Abort.
           // (It cannot be any useful data of the PO file, as otherwise the line would start with at least a quote)
@@ -429,7 +431,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 
            }
            // one of the quotation marks is missing
-           else if(KDE_ISUNLIKELY( /*_testBorked&&*/ line.contains( _rxMsgIdBorked ) ))
+           else if(Q_UNLIKELY( /*_testBorked&&*/ line.contains( _rxMsgIdBorked ) ))
            {
                part=Msgid;
 
@@ -486,7 +488,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                (*(_msgid).begin())=line;
             }
             // one of the quotation marks is missing
-            else if(KDE_ISUNLIKELY( /*_testBorked&&*/line.contains( _rxMsgIdBorked ) ))
+            else if(Q_UNLIKELY( /*_testBorked&&*/line.contains( _rxMsgIdBorked ) ))
             {
                part=Msgid;
 
@@ -536,7 +538,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                (*(_msgid).begin())=line;
             }
             // one of the quotation marks is missing
-            else if(KDE_ISUNLIKELY(/*_testBorked&&*/ line.contains ( _rxMsgIdBorked ) ))
+            else if(Q_UNLIKELY(/*_testBorked&&*/ line.contains ( _rxMsgIdBorked ) ))
             {
                part=Msgid;
 
@@ -594,7 +596,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                _msgid.append(line);
             }
             // one of the quotation marks is missing
-            else if(KDE_ISUNLIKELY(/*_testBorked&&*/ line.contains( _rxMsgIdPluralBorked ) ))
+            else if(Q_UNLIKELY(/*_testBorked&&*/ line.contains( _rxMsgIdPluralBorked ) ))
             {
                part=Msgid;
                _gettextPluralForm = true;
@@ -644,7 +646,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                _msgstrMultiline=line.isEmpty();
                (*msgstrIt)=line;
             }
-            else if(KDE_ISUNLIKELY( /*_testBorked&&*/ _gettextPluralForm &&  line.contains( _rxMsgStrPluralStartBorked ) ))
+            else if(Q_UNLIKELY( /*_testBorked&&*/ _gettextPluralForm &&  line.contains( _rxMsgStrPluralStartBorked ) ))
             {
                part=Msgstr;
 
@@ -672,7 +674,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                break;
             }
             // a line of the msgid with a missing quotation mark
-            else if(KDE_ISUNLIKELY( /*_testBorked&&*/line.contains( _rxMsgLineBorked ) ))
+            else if(Q_UNLIKELY( /*_testBorked&&*/line.contains( _rxMsgLineBorked ) ))
             {
                recoverableError=true;
 
@@ -733,7 +735,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                _bufferedLine=line;
                break;
             }
-            else if(KDE_ISUNLIKELY(/*_testBorked&&*/ _gettextPluralForm && ( line.contains( _rxMsgStrPluralBorked ) ) ))
+            else if(Q_UNLIKELY(/*_testBorked&&*/ _gettextPluralForm && ( line.contains( _rxMsgStrPluralBorked ) ) ))
             {
                // remove quotes at beginning and the end of the lines
                line.remove(QRegExp(QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?")));
@@ -753,7 +755,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                break;
             }
             // another line of the msgstr with a missing quotation mark
-            else if(KDE_ISUNLIKELY( /*_testBorked&&*/line.contains( _rxMsgLineBorked ) ))
+            else if(Q_UNLIKELY( /*_testBorked&&*/line.contains( _rxMsgLineBorked ) ))
             {
                recoverableError=true;
 
@@ -791,9 +793,9 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
   */
 
     //qDebug() << " NEAR RETURN";
-    if(KDE_ISUNLIKELY(error))
+    if(Q_UNLIKELY(error))
         return PARSE_ERROR;
-    else if(KDE_ISUNLIKELY(recoverableError))
+    else if(Q_UNLIKELY(recoverableError))
         return RECOVERED_PARSE_ERROR;
     else
         return OK;
