@@ -56,6 +56,11 @@ struct langPInfo
 
 static const langPInfo langsWithPInfo[] = {
     { "ar", "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;" },
+    { "be@latin", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
+    { "be", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
+    { "br", "nplurals=1; plural=0;" },
+    { "bs", "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;" },
+    { "csb", "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)" },
     { "cs", "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;" },
     { "da", "nplurals=2; plural=(n != 1);" },
     { "de", "nplurals=2; plural=(n != 1);" },
@@ -66,21 +71,38 @@ static const langPInfo langsWithPInfo[] = {
     { "eo", "nplurals=2; plural=(n != 1);" },
     { "es", "nplurals=2; plural=(n != 1);" },
     { "et", "nplurals=2; plural=(n != 1);" },
+    { "fa", "nplurals=1; plural=0;" },
     { "fi", "nplurals=2; plural=(n != 1);" },
     { "fo", "nplurals=2; plural=(n != 1);" },
     { "fr", "nplurals=2; plural=(n > 1);" },
-    { "ga", "nplurals=3; plural=n==1 ? 0 : n==2 ? 1 : 2;" },
+    { "ga", "nplurals=5; plural=n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n < 11 ? 3 : 4" },
+    { "gd", "nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;" },
+    { "gu", "nplurals=2; plural=(n!=1);" },
     { "he", "nplurals=2; plural=(n != 1);" },
+    { "hi", "nplurals=2; plural=(n!=1);" },
+    { "hne", "nplurals=2; plural=(n!=1);" },
     { "hr", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
+    { "hsb", "nplurals=4; plural=n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3;" },
     { "hu", "nplurals=2; plural=(n != 1);" },
+    { "hy", "nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;" },
+    { "id", "nplurals=1; plural=0;" },
     { "it", "nplurals=2; plural=(n != 1);" },
     { "ja", "nplurals=1; plural=0;" },
+    { "ka", "nplurals=1; plural=0;" },
+    { "kk", "nplurals=1; plural=0;" },
+    { "km", "nplurals=1; plural=0;" },
     { "ko", "nplurals=1; plural=0;" },
     { "lt", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);" },
     { "lv", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);" },
+    { "mai", "nplurals=2; plural=(n!=1);" },
+    { "mk", "nplurals=3; plural=n%10==1 ? 0 : n%10==2 ? 1 : 2;" },
+    { "mr", "nplurals=2; plural=(n!=1);" },
+    { "ms", "nplurals=2; plural=1;" },
     { "nb", "nplurals=2; plural=(n != 1);" },
     { "nl", "nplurals=2; plural=(n != 1);" },
     { "nn", "nplurals=2; plural=(n != 1);" },
+    { "oc", "nplurals=2; plural=(n > 1);" },
+    { "or", "nplurals=2; plural=(n!=1);" },
     { "pl", "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
     { "pt", "nplurals=2; plural=(n != 1);" },
     { "pt_BR", "nplurals=2; plural=(n > 1);" },
@@ -91,11 +113,17 @@ static const langPInfo langsWithPInfo[] = {
     { "sr", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
     { "sr@latin", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
     { "sv", "nplurals=2; plural=(n != 1);" },
+    { "te", "nplurals=5; plural=n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4;" },
     { "th", "nplurals=1; plural=0;" },
     { "tr", "nplurals=2; plural=(n > 1);" },
+    { "ug", "nplurals=1; plural=0;" },
     { "uk", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);" },
+    { "uz", "nplurals=1; plural=0;" },
+    { "uz@cyrillic", "nplurals=1; plural=0;" },
     { "vi", "nplurals=1; plural=0;" },
-    { "zh_CN", "nplurals=1; plural=0;" }
+    { "zh_CN", "nplurals=1; plural=0;" },
+    { "zh_HK", "nplurals=1; plural=0;" },
+    { "zh_TW", "nplurals=1; plural=0;" }
 };
 
 static const size_t langsWithPInfoCount = sizeof (langsWithPInfo) / sizeof (langsWithPInfo[0]);
